@@ -3,12 +3,14 @@
 """
 Copyright (c) 2018-2020 Kairo de Araujo
 """
+import os
+
 
 # CA directories and files
 CA_PRIVATE_DIR = "private"
 CA_CERTS_DIR = "certs"
 CA_CERT = "ca.crt"
-CA_KEY = f"{CA_PRIVATE_DIR}/ca_key.pem"
+CA_KEY = os.path.join(CA_PRIVATE_DIR, "ca_key.pem")
 CA_PUBLIC_KEY = "ca_key.pub"
 CA_CRL = "ca.crl"
 CA_CSR = "ca.csr"
